@@ -1,4 +1,15 @@
-//@line 39 "/Srcs/Xulrunner/build/toolkit/content/nsDragAndDrop.js"
+//@line 39 "/home/karma/src/xulrunner/build/toolkit/content/nsDragAndDrop.js"
+
+////////////////////////////////////////////////////////////////////////
+//
+// USE OF THIS API FOR DRAG AND DROP IS DEPRECATED!
+// Do not use this file for new code.
+//
+// For documentation about what to use instead, see:
+//   http://developer.mozilla.org/En/DragDrop/Drag_and_Drop
+//
+////////////////////////////////////////////////////////////////////////
+
 
 /** 
  *  nsTransferable - a wrapper for nsITransferable that simplifies
@@ -537,10 +548,6 @@ var nsDragAndDrop = {
    **/
   dragDropSecurityCheck: function (aEvent, aDragSession, aDraggedText)
     {
-      var sourceDoc = aDragSession.sourceDocument;
-      if (!sourceDoc)
-        return;
-
       // Strip leading and trailing whitespace, then try to create a
       // URI from the dropped string. If that succeeds, we're
       // dropping a URI and we need to do a security check to make
@@ -569,8 +576,16 @@ var nsDragAndDrop = {
       var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                              .getService(nsIScriptSecurityManager);
 
+      if (!aDragSession)
+        aDragSession = this.mDragService.getCurrentSession();
+
+      var sourceDoc = aDragSession.sourceDocument;
+      // Use "file:///" as the default sourceURI so that drops of file:// URIs
+      // are always allowed.
+      var sourceURI = sourceDoc ? sourceDoc.documentURI : "file:///";
+
       try {
-        secMan.checkLoadURIStr(sourceDoc.documentURI, aDraggedText,
+        secMan.checkLoadURIStr(sourceURI, aDraggedText,
                                nsIScriptSecurityManager.STANDARD);
       } catch (e) {
         // Stop event propagation right here.
